==> smake-1.2a28.tar.bz2: smake-1.2/smake/rules.c <==
/* @(#)rules.c	1.13 03/11/26 Copyright 1987 J. Schilling */
#ifndef lint
static	char sccsid[] =
	"@(#)rules.c	1.13 03/11/26 Copyright 1987 J. Schilling";
#endif
/*
 *	Copyright (c) 1987 J. Schilling
 */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; see the file COPYING.  If not, write to the Free Software
 * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <mconfig.h>
#include <stdio.h>
#include <standard.h>
#include "make.h"

/*
 * Default rules complied into make.
 *
 * Should rather read in a setup file...
 */
char implicit_rules[] =


#if	defined(unix) || defined(IS_UNIX) || defined(IS_GCC_WIN32) || \
	defined(__EMX__) || defined(__BEOS__) || defined(__DJGPP__)
#	define _OS_

"\
FC=	f77\n\
RC=	f77\n\
PC=	pc\n\
AS=	as\n\
CC=	cc\n\
LD=	ld\n\
LEX= 	lex\n\
MAKE=	smake\n\
YACCR=	yacc -r\n\
YACC=	yacc\n\
ROFF=	nroff\n\
ASFLAGS=\n\
FFLAGS=\n\
LDFLAGS=\n\
RFLAGS=	-ms\n\
YFLAGS=\n\
.o: .c .s .l\n\
	$(CC) -c $(CFLAGS) $(CPPFLAGS) $<\n\
	$(AS) -o $*.o $(ASFLAGS) $<\n\
	$(LEX) $(LFLAGS) $<;$(CC) -c $(CFLAGS) lex.yy.c;rm lex.yy.c;mv lex.yy.o $@\n\
.c: .y\n\
	$(YACC) $(YFLAGS) $<;mv y.tab.c $@\n\
\"\": .o .sc\n\
	$(CC) -o $* $<\n\
	$(ROFF) $(RFLAGS) $< > $@\n";
#endif

#ifdef	tos
#	define _OS_

"\
FC=	f77\n\
RC=	f77\n\
PC=	pc\n\
AS=	as\n\
CC=	cc\n\
LD=	ld\n\
LEX= 	lex\n\
MAKE=	smake\n\
YACCR=	yacc -r\n\
YACC=	yacc\n\
ROFF=	nroff\n\
ASFLAGS=\n\
FFLAGS=\n\
LDFLAGS=\n\
RFLAGS=	-ms\n\
.o: .c .s .l\n\
	$(CC) -c $(CFLAGS) $(CPPFLAGS) $<\n\
	$(AS) -o $*.o $(ASFLAGS) $<\n\
	$(LEX) $(LFLAGS) $<;$(CC) -c $(CFLAGS) lexyy.c;rm lexyy.c;mv lexyy.o $@\n\
.c: .y\n\
	$(YACC) $(YFLAGS) $<;mv ytab.c $@\n\
\"\": .sc\n\
	$(ROFF) $(RFLAGS) $< > $@\n\
.prg .tos .ttp: .o\n\
	$(CC) -o $* $<\n";
#endif

#ifndef _OS_
"";
#endif

==> smake-1.2.5.tar.bz2: smake-1.2.5/smake/rules.c <==
/* @(#)rules.c	1.19 09/08/28 Copyright 1987-2009 J. Schilling */
#include <schily/mconfig.h>
#ifndef lint
static	UConst char sccsid[] =
	"@(#)rules.c	1.19 09/08/28 Copyright 1987-2009 J. Schilling";
#endif
/*
 *	Copyright (c) 1987-2009 J. Schilling
 */
/*
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * See the file CDDL.Schily.txt in this distribution for details.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file CDDL.Schily.txt from this distribution.
 */

#include <schily/stdio.h>
#include <schily/standard.h>
#include "make.h"

/*
 * Default rules complied into make.
 *
 * Should rather read in a setup file...
 */
char implicit_rules[] =


#if	defined(unix) || defined(IS_UNIX) || defined(IS_GCC_WIN32) || \
	defined(__EMX__) || defined(__BEOS__) || defined(__HAIKU__) || \
	defined(__DJGPP__)
#	define _OS_

"\
FC=	f77\n\
RC=	f77\n\
PC=	pc\n\
AS=	as\n\
CC=	cc\n\
LD=	ld\n\
LEX= 	lex\n\
MAKE=	smake\n\
YACCR=	yacc -r\n\
YACC=	yacc\n\
ROFF=	nroff\n\
ASFLAGS=\n\
FFLAGS=\n\
LDFLAGS=\n\
RFLAGS=	-ms\n\
YFLAGS=\n\
.o: .c .s .l\n\
	$(CC) -c $(CFLAGS) $(CPPFLAGS) $<\n\
	$(AS) -o $*.o $(ASFLAGS) $<\n\
	$(LEX) $(LFLAGS) $<;$(CC) -c $(CFLAGS) lex.yy.c;rm lex.yy.c;mv lex.yy.o $@\n\
.c: .y\n\
	$(YACC) $(YFLAGS) $<;mv y.tab.c $@\n\
\"\": .o .sc\n\
	$(CC) -o $* $<\n\
	$(ROFF) $(RFLAGS) $< > $@\n";
#endif

#ifdef	tos
#	define _OS_

"\
FC=	f77\n\
RC=	f77\n\
PC=	pc\n\
AS=	as\n\
CC=	cc\n\
LD=	ld\n\
LEX= 	lex\n\
MAKE=	smake\n\
YACCR=	yacc -r\n\
YACC=	yacc\n\
ROFF=	nroff\n\
ASFLAGS=\n\
FFLAGS=\n\
LDFLAGS=\n\
RFLAGS=	-ms\n\
.o: .c .s .l\n\
	$(CC) -c $(CFLAGS) $(CPPFLAGS) $<\n\
	$(AS) -o $*.o $(ASFLAGS) $<\n\
	$(LEX) $(LFLAGS) $<;$(CC) -c $(CFLAGS) lexyy.c;rm lexyy.c;mv lexyy.o $@\n\
.c: .y\n\
	$(YACC) $(YFLAGS) $<;mv ytab.c $@\n\
\"\": .sc\n\
	$(ROFF) $(RFLAGS) $< > $@\n\
.prg .tos .ttp: .o\n\
	$(CC) -o $* $<\n";
#endif

#ifndef _OS_
"";
#endif
